pyxmpp2.settings._SettingDefinition

Package pyxmpp2 :: Module settings :: Class _SettingDefinition |
[hide private]

# Class _SettingDefinition

A PyXMPP2 setting meta-data and defaults.

Instance Methods | [hide private]
__init__(self, name, type=<type 'unicode'>, default=None, factory=None, cache=False, default_d=None, doc=None, cmdline_help=None, validator=None, basic=False) x.__init__(...) initializes x; see help(type(x)) for signature |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, name, type=<type 'unicode'>, default=None, factory=None, cache=False, default_d=None, doc=None, cmdline_help=None, validator=None, basic=False) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)